==> pwsafe-3.09-src.zip: pwsafe-3.09-src/corelib/corelib.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_EXPHDRGROUPTITLE           3003
#define IDSC_EXPHDRUSERNAME             3004
#define IDSC_EXPHDRPASSWORD             3005
#define IDSC_EXPHDRURL                  3006
#define IDSC_EXPHDRAUTOTYPE             3007
#define IDSC_EXPHDRCTIME                3008
#define IDSC_EXPHDRPMTIME               3009
#define IDSC_EXPHDRATIME                3010
#define IDSC_EXPHDRLTIME                3011
#define IDSC_EXPHDRRMTIME               3012
#define IDSC_EXPHDRPWHISTORY            3013
#define IDCS_EXPHDRNOTES                3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTGETLOCKER              3020
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_XMLPARSEERROR              3043
#define IDSC_XMLBADCREATESCHEMA         3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOXMLREADER                3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_SAXGENERROR                3053
                                        
#define IDSC_FILEEXCEPTION00            3100
#define IDSC_FILEEXCEPTION01            3101
#define IDSC_FILEEXCEPTION02            3102
#define IDSC_FILEEXCEPTION03            3103
#define IDSC_FILEEXCEPTION04            3104
#define IDSC_FILEEXCEPTION05            3105
#define IDSC_FILEEXCEPTION06            3106
#define IDSC_FILEEXCEPTION07            3107
#define IDSC_FILEEXCEPTION08            3108
#define IDSC_FILEEXCEPTION09            3109
#define IDSC_FILEEXCEPTION10            3110
#define IDSC_FILEEXCEPTION11            3111
#define IDSC_FILEEXCEPTION12            3112
#define IDSC_FILEEXCEPTION13            3113
#define IDSC_FILEEXCEPTION14            3114
                                        
#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND IDSC_FILEEXCEPTION02
#define IDSC_BADPASSWORD                3251

==> pwsafe-3.10-src.zip: pwsafe-3.10-src/corelib/corelib.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_EXPHDRGROUPTITLE           3003
#define IDSC_EXPHDRUSERNAME             3004
#define IDSC_EXPHDRPASSWORD             3005
#define IDSC_EXPHDRURL                  3006
#define IDSC_EXPHDRAUTOTYPE             3007
#define IDSC_EXPHDRCTIME                3008
#define IDSC_EXPHDRPMTIME               3009
#define IDSC_EXPHDRATIME                3010
#define IDSC_EXPHDRLTIME                3011
#define IDSC_EXPHDRRMTIME               3012
#define IDSC_EXPHDRPWHISTORY            3013
#define IDCS_EXPHDRNOTES                3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTGETLOCKER              3020
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_XMLPARSEERROR              3043
#define IDSC_XMLBADCREATESCHEMA         3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOXMLREADER                3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_SAXGENERROR                3053
#define IDSC_EXPHDRGROUP                3054
#define IDSC_EXPHDRTITLE                3055
                                        
#define IDSC_FILEEXCEPTION00            3100
#define IDSC_FILEEXCEPTION01            3101
#define IDSC_FILEEXCEPTION02            3102
#define IDSC_FILEEXCEPTION03            3103
#define IDSC_FILEEXCEPTION04            3104
#define IDSC_FILEEXCEPTION05            3105
#define IDSC_FILEEXCEPTION06            3106
#define IDSC_FILEEXCEPTION07            3107
#define IDSC_FILEEXCEPTION08            3108
#define IDSC_FILEEXCEPTION09            3109
#define IDSC_FILEEXCEPTION10            3110
#define IDSC_FILEEXCEPTION11            3111
#define IDSC_FILEEXCEPTION12            3112
#define IDSC_FILEEXCEPTION13            3113
#define IDSC_FILEEXCEPTION14            3114
                                        
#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND IDSC_FILEEXCEPTION02
#define IDSC_BADPASSWORD                3251

#define IDSC_REPORTFILENAME             3252
#define IDSC_REPORT_TITLE1              3253
#define IDSC_REPORT_TITLE2              3254
#define IDSC_START_REPORT               3255
#define IDSC_END_REPORT1                3256
#define IDSC_END_REPORT2                3257

#define IDSC_IMPORTNOHEADER             3258
#define IDSC_IMPORTLINESKIPPED          3259
#define IDSC_IMPORTKNOWNHDRS            3260
#define IDSC_IMPORTEMPTYLINESKIPPED     3261
#define IDSC_PWHERRORLINE               3262
#define IDSC_PWHISTORYSKIPPED           3263
#define IDSC_IMPORTCONFLICTS1           3264
#define IDSC_IMPORTCONFLICTS2           3265
#define IDSC_IMPORTINVALIDFIELD         3266
#define IDSC_READNUMBER                 3267
#define IDSC_IMPORTNOPASSWORD           3268
#define IDSC_IMPORTNOTITLE              3269
#define IDSC_VALIDATEUUID               3270
#define IDSC_VALIDATEPWH                3271
